# Copyright (C) 2018 Svetlana Tkachenko svetlana@members.fsf.org
#
#    This file is part of WeABit, Welcome-a-bit for Wikinews.
#
#    WeABit is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    WeABit is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with WeABit.  If not, see <https://www.gnu.org/licenses/>.

package wabdeliver;

use strict;
use warnings;

use MediaWiki::API;
use LWP::Simple;

use URI::Escape;

use Data::Dumper;

use wabts;

my $mw = MediaWiki::API->new();



# *** deliver a list to a particular user using a particular delivery type ***
# input: list, username, deliveryType
# "deliveryType" = wiki or email
# "list" is a multiline string on this particular topic :)
sub _deliver{
    my $hr = shift;
    
    if($hr->{deliveryType} eq 'email'){
		
		
		
		my $wikiURL = $hr->{wikiURL};
		$mw->{config}->{api_url} = "$wikiURL/w/api.php";
		
		#log in to the wiki
		$mw->login( {lgname => 'Gryllida', lgpassword => '***' } )
			|| die $mw->{error}->{code} . ': ' . $mw->{error}->{details};
			
			# https://en.wikipedia.org/w/api.php?action=query&meta=tokens
		my $token = $mw->api({'action'=>'query','meta'=>'tokens'})->{query}->{tokens}->{csrftoken};
		print Dumper $token;
		
		# action=emailuser&target=Catrope&subject=Hi&text=Just%20wanted%20to%20say%20hi&token=58b54e0bab4a1d3fd3f7653af38e75cb+\
		my $result = $mw->api ( {
			'action' => 'emailuser',
			'target' => $hr->{username},
			'subject' => 'Wikinews about ' . $hr->{cat},
			'text' => $hr->{list},
			'token' => $token
		}) || die $mw->{error}->{code} . ': ' . $mw->{error}->{details};

		print "Result: ";
		print Dumper $result;
		print "... done.\r\n";
			
		
	}
}

# *** check a category for entries added after userTs ***
# input: cat, username, deliveryType, userTs
sub _notify_user{
	my $self = shift;
    my $hr = shift; #hash ref
    
    my $wikiURL = $hr->{wikiURL};
    $mw->{config}->{api_url} = "$wikiURL/w/api.php";
    
    my $username = $hr->{username};
    
    my $cat = $hr->{cat};
    print "... [$cat]: Notifying $username of new entries...\r\n";
    #my $category_one_entry_ref = $mw->api ( {
    #    action  => 'query',
    #    list    => 'categorymembers',
    #    cmtitle => "Category:$cat",
    #    cmprop  => 'timestamp|title',
    #    cmsort  => 'timestamp',
    #    cmdir   => 'desc',
    #    cmlimit => 100
    #});
    #my $array = $category_one_entry_ref->{query}->{categorymembers};
    #my $list = '';
	my @entries = $hr->{entries}->[0];  
	my $list = "";
    for my $entry (@entries){
		print "Entry: ";
		print Dumper $entry;
		print "... that was the entry.\r\n";
		my $tsEpoch = wabts->parseTsFromAtomFeed($entry->{dt});
		if($tsEpoch <= $hr->{userTs}){
			last;
		}
		my $title = $entry->{title};
		my $title2 = uri_escape_utf8($title);
		my $url = "$wikiURL/wiki/$title2";
		
		
		my $dt = DateTime->from_epoch( epoch => $tsEpoch);
		my $dt1 = $dt->ymd;
		my $dt2 = $dt->hms;
		
		
		$list = "$list\r\n$title (added at $dt1 $dt2, epoch $tsEpoch)\r\n $url\r\n";
	};
	print Dumper $list;
	_deliver({
		list => $list, 
		username => $username,
		deliveryType => $hr->{deliveryType},
		'mw' => $mw,
		'wikiURL' => $wikiURL,
		'cat' => $cat
	});
    
    
}

1;

#_ _END_ _
